@@ -27,6 +27,8 @@
 #ifndef __G_LIB_H__
 #define __G_LIB_H__
 
+#include <sys/param.h>
+
 /* system specific config file glibconfig.h provides definitions for
  * the extrema of many of the standard types. These are:
  *
@@ -88,6 +90,7 @@
 
 #else  /* !NATIVE_WIN32 */
 
+#ifndef __EMX__
 /* Unix */
 
 #define G_DIR_SEPARATOR '/'
@@ -95,6 +98,16 @@
 #define G_SEARCHPATH_SEPARATOR ':'
 #define G_SEARCHPATH_SEPARATOR_S ":"
 
+#else
+/* EMX/OS2 */
+
+#define G_DIR_SEPARATOR '/'
+#define G_DIR_SEPARATOR_S "/"
+#define G_SEARCHPATH_SEPARATOR ';'
+#define G_SEARCHPATH_SEPARATOR_S ";"
+
+#endif
+
 #endif /* !NATIVE_WIN32 */
 
 #ifdef __cplusplus
@@ -119,11 +132,13 @@ extern "C" {
 #define	TRUE	(!FALSE)
 #endif
 
-#undef	MAX
+#ifndef MAX
 #define MAX(a, b)  (((a) > (b)) ? (a) : (b))
+#endif
 
-#undef	MIN
+#ifndef MIN
 #define MIN(a, b)  (((a) < (b)) ? (a) : (b))
+#endif
 
 #undef	ABS
 #define ABS(a)	   (((a) < 0) ? -(a) : (a))
@@ -262,11 +277,11 @@ extern "C" {
  * macros, so we can refer to them as strings unconditionally.
  */
 #ifdef	__GNUC__
-#define	G_GNUC_FUNCTION		(__FUNCTION__)
-#define	G_GNUC_PRETTY_FUNCTION	(__PRETTY_FUNCTION__)
+#define	G_GNUC_FUNCTION		__FUNCTION__
+#define	G_GNUC_PRETTY_FUNCTION	__PRETTY_FUNCTION__
 #else	/* !__GNUC__ */
-#define	G_GNUC_FUNCTION		("")
-#define	G_GNUC_PRETTY_FUNCTION	("")
+#define	G_GNUC_FUNCTION		""
+#define	G_GNUC_PRETTY_FUNCTION	""
 #endif	/* !__GNUC__ */
 
 /* we try to provide a usefull equivalent for ATEXIT if it is
@@ -702,6 +717,7 @@ typedef struct _GTuples		GTuples;
 typedef union  _GTokenValue	GTokenValue;
 typedef struct _GIOChannel	GIOChannel;
 
+/* Tree traverse flags */
 typedef enum
 {
   G_TRAVERSE_LEAFS	= 1 << 0,
@@ -710,6 +726,7 @@ typedef enum
   G_TRAVERSE_MASK	= 0x03
 } GTraverseFlags;
 
+/* Tree traverse orders */
 typedef enum
 {
   G_IN_ORDER,
@@ -1745,6 +1762,7 @@ gchar*	  g_quark_to_string		(GQuark		 quark);
 
 
 /* Keyed Data List
+ * NOTE: these functions are scheduled for a rename in GLib 1.3
  */
 void	  g_datalist_init		 (GData		 **datalist);
 void	  g_datalist_clear		 (GData		 **datalist);
@@ -1776,6 +1794,7 @@ void	  g_datalist_foreach		 (GData		 **datalist,
 
 
 /* Location Associated Keyed Data
+ * NOTE: these functions are scheduled for a rename in GLib 1.3
  */
 void	  g_dataset_destroy		(gconstpointer	  dataset_location);
 gpointer  g_dataset_id_get_data		(gconstpointer	  dataset_location,
@@ -2406,7 +2425,7 @@ struct _GSourceFuncs
 			GTimeVal *current_time,
 			gpointer  user_data);
   gboolean (*dispatch) (gpointer  source_data, 
-			GTimeVal *current_time,
+			GTimeVal *dispatch_time,
 			gpointer  user_data);
   GDestroyNotify destroy;
 };
@@ -2434,7 +2453,7 @@ gboolean g_source_remove_by_source_data      (gpointer       source_data);
 gboolean g_source_remove_by_funcs_user_data  (GSourceFuncs  *funcs,
 					      gpointer       user_data);
 
-void g_get_current_time		    (GTimeVal	   *result);
+void g_get_current_time		        (GTimeVal	*result);
 
 /* Running the main loop */
 GMainLoop*	g_main_new		(gboolean	 is_running);
@@ -2675,7 +2694,7 @@ GUTILS_C_VAR gboolean		g_threads_got_initialized;
  * only be called once, and must not be called directly or indirectly
  * from another glib-function, e.g. as a callback.
  */
-void	g_thread_init	(GThreadFunctions	*vtable);
+void   g_thread_init   (GThreadFunctions       *vtable);
 
 /* internal function for fallback static mutex implementation */
 GMutex*	g_static_mutex_get_mutex_impl	(GMutex	**mutex);
