@@ -32,7 +32,7 @@ typedef unsigned short guint16;
 typedef signed int gint32;
 typedef unsigned int guint32;
 
-#if defined (__GNUC__) && __GNUC__ >= 2 && __GNUC_MINOR__ >= 8
+#if defined (__GNUC__) && (__GNUC__ > 2 || (__GNUC__ == 2 && __GNUC_MINOR__ >= 8))
 #  define G_GNUC_EXTENSION __extension__
 #else
 #  define G_GNUC_EXTENSION
@@ -61,7 +61,7 @@ G_GNUC_EXTENSION typedef unsigned long long guint64;
 
 #define GLIB_MAJOR_VERSION 1
 #define GLIB_MINOR_VERSION 2
-#define GLIB_MICRO_VERSION 7
+#define GLIB_MICRO_VERSION 8
 
 
 
